@@ -119,16 +119,6 @@ extern "C" {
     "legacy", \
     "Which type of transform to use to calculate cepstra (legacy, dct, or htk)" }, \
    \
-  { "-spec2cep", \
-    ARG_BOOLEAN, \
-    "no", \
-    "Input is log spectral files, output is cepstral files" }, \
-   \
-  { "-cep2spec", \
-    ARG_BOOLEAN, \
-    "no", \
-    "Input is cepstral files, output is log spectral files" }, \
-   \
   { "-alpha", \
     ARG_FLOAT32, \
     ARG_STRINGIFY(DEFAULT_PRE_EMPHASIS_ALPHA), \
@@ -203,12 +193,12 @@ extern "C" {
     ARG_STRING, \
     DEFAULT_WARP_TYPE, \
     "Warping function type (or shape)" }, \
- \
+   \
   { "-warp_params", \
     ARG_STRING, \
     NULL, \
     "Parameters defining the warping function" }, \
- \
+   \
   { "-dither", \
     ARG_BOOLEAN, \
     "no", \
@@ -218,16 +208,17 @@ extern "C" {
     ARG_INT32, \
     ARG_STRINGIFY(SEED), \
     "Seed for random number generator; if less than zero, pick our own" }, \
- \
+   \
   { "-remove_dc", \
     ARG_BOOLEAN, \
     "no", \
     "Remove DC offset from each frame" }, \
-   \
+                                          \
   { "-verbose", \
     ARG_BOOLEAN, \
     "no", \
-    "Show input filenames" }
+    "Show input filenames" } \
+  
   
 #ifdef FIXED_POINT
 /** MFCC computation type. */
@@ -441,9 +432,10 @@ int fe_process_frame(fe_t *fe, int16 const *spch,
  *                     process.
  *                     Output: Number of samples remaining in input buffer.
  * @param buf_cep Two-dimensional buffer (allocated with
- *                ckd_calloc_2d()) which will receive frames of output data.
- *                If NULL, no actual processing will be done, and the number
- *                of output frames which would be generated is returned in
+ *                ckd_calloc_2d()) which will receive frames of output
+ *                data.  If NULL, no actual processing will be done,
+ *                and the maximum number of output frames which would
+ *                be generated is returned in
  *                <code>*inout_nframes</code>.
  * @param inout_nframes Input: Pointer to maximum number of frames to
  *                      generate.
@@ -529,8 +521,8 @@ int fe_float_to_mfcc(fe_t *fe,
  **/
 SPHINXBASE_EXPORT
 int fe_logspec_to_mfcc(fe_t *fe,  /**< A fe structure */
-			 const mfcc_t *fr_spec, /**< One frame of spectrum */
-			 mfcc_t *fr_cep /**< One frame of cepstrum */
+                       const mfcc_t *fr_spec, /**< One frame of spectrum */
+                       mfcc_t *fr_cep /**< One frame of cepstrum */
         );
 
 /**
@@ -543,8 +535,8 @@ int fe_logspec_to_mfcc(fe_t *fe,  /**< A fe structure */
  **/
 SPHINXBASE_EXPORT
 int fe_logspec_dct2(fe_t *fe,  /**< A fe structure */
-		      const mfcc_t *fr_spec, /**< One frame of spectrum */
-		      mfcc_t *fr_cep /**< One frame of cepstrum */
+                    const mfcc_t *fr_spec, /**< One frame of spectrum */
+                    mfcc_t *fr_cep /**< One frame of cepstrum */
         );
 
 /**
