@@ -73,10 +73,11 @@ typedef struct ngram_class_s ngram_class_t;
  * File types for N-Gram files
  */
 typedef enum ngram_file_type_e {
-    NGRAM_AUTO,  /**< Determine file type automatically */
-    NGRAM_ARPA,  /**< ARPABO text format (the standard) */
-    NGRAM_DMP,   /**< Sphinx .DMP format */
-    NGRAM_DMP32  /**< Sphinx .DMP32 format */
+    NGRAM_INVALID = -1, /**< Not a valid file type. */
+    NGRAM_AUTO,  /**< Determine file type automatically. */
+    NGRAM_ARPA,  /**< ARPABO text format (the standard). */
+    NGRAM_DMP,   /**< Sphinx .DMP format. */
+    NGRAM_DMP32, /**< Sphinx .DMP32 format (NOT SUPPORTED) */
 } ngram_file_type_t;
 
 #define NGRAM_INVALID_WID -1 /**< Impossible word ID */
@@ -110,14 +111,37 @@ ngram_model_t *ngram_model_read(cmd_ln_t *config,
 /**
  * Write an N-Gram model to disk.
  *
- * @note This is not yet implemented.
- *
  * @return 0 for success, <0 on error
  */
 SPHINXBASE_EXPORT
 int ngram_model_write(ngram_model_t *model, const char *file_name,
 		      ngram_file_type_t format);
 
+/**
+ * Guess the file type for an N-Gram model from the filename.
+ *
+ * @return the guessed file type, or NGRAM_INVALID if none could be guessed.
+ */
+SPHINXBASE_EXPORT
+ngram_file_type_t ngram_file_name_to_type(const char *file_name);
+
+/**
+ * Get the N-Gram file type from a string.
+ *
+ * @return file type, or NGRAM_INVALID if no such file type exists.
+ */
+SPHINXBASE_EXPORT
+ngram_file_type_t ngram_str_to_type(const char *str_name);
+
+/**
+ * Get the canonical name for an N-Gram file type.
+ *
+ * @return read-only string with the name for this file type, or NULL
+ * if no such type exists.
+ */
+SPHINXBASE_EXPORT
+char const *ngram_type_to_str(int type);
+
 /**
  * Retain ownership of an N-Gram model.
  *
@@ -153,6 +177,23 @@ int ngram_model_free(ngram_model_t *model);
 SPHINXBASE_EXPORT
 int ngram_model_recode(ngram_model_t *model, const char *from, const char *to);
 
+/**
+ * Constants for case folding.
+ */
+typedef enum ngram_case_e {
+    NGRAM_UPPER,
+    NGRAM_LOWER
+} ngram_case_t;
+
+/**
+ * Case-fold word strings in an N-Gram model.
+ *
+ * WARNING: This is not Unicode aware, so any non-ASCII characters
+ * will not be converted.
+ */
+SPHINXBASE_EXPORT
+int ngram_model_casefold(ngram_model_t *model, int kase);
+
 /**
  * Apply a language weight, insertion penalty, and unigram weight to a
  * language model.
@@ -316,11 +357,71 @@ SPHINXBASE_EXPORT
 int32 ngram_model_get_size(ngram_model_t *model);
 
 /**
- * Get the counts of the various N-grams in the model
+ * Get the counts of the various N-grams in the model.
  */
 SPHINXBASE_EXPORT
 int32 const *ngram_model_get_counts(ngram_model_t *model);
 
+/**
+ * M-gram iterator object.
+ */
+typedef struct ngram_iter_s ngram_iter_t;
+
+/**
+ * Iterate over all M-grams.
+ *
+ * @param model Language model to query.
+ * @param m Order of the M-Grams requested minus one (i.e. order of the history)
+ * @return An iterator over the requested M, or NULL if no N-grams of
+ * order M+1 exist.
+ */
+SPHINXBASE_EXPORT
+ngram_iter_t *ngram_model_mgrams(ngram_model_t *model, int m);
+
+/**
+ * Get an iterator over M-grams pointing to the specified M-gram.
+ */
+SPHINXBASE_EXPORT
+ngram_iter_t *ngram_iter(ngram_model_t *model, const char *word, ...);
+
+/**
+ * Get an iterator over M-grams pointing to the specified M-gram.
+ */
+SPHINXBASE_EXPORT
+ngram_iter_t *ngram_ng_iter(ngram_model_t *model, int32 wid, int32 *history, int32 n_hist);
+
+/**
+ * Get information from the current M-gram in an iterator.
+ *
+ * @param out_score Output: Score for this M-gram (including any word
+ *                          penalty and language weight).
+ * @param out_bowt Output: Backoff weight for this M-gram.
+ * @return read-only array of word IDs.
+ */
+SPHINXBASE_EXPORT
+int32 const *ngram_iter_get(ngram_iter_t *itor,
+                            int32 *out_score,
+                            int32 *out_bowt);
+
+/**
+ * Iterate over all M-gram successors of an M-1-gram.
+ *
+ * @param itor Iterator pointing to the M-1-gram to get successors of.
+ */
+SPHINXBASE_EXPORT
+ngram_iter_t *ngram_iter_successors(ngram_iter_t *itor);
+
+/**
+ * Advance an M-gram iterator.
+ */
+SPHINXBASE_EXPORT
+ngram_iter_t *ngram_iter_next(ngram_iter_t *itor);
+
+/**
+ * Terminate an M-gram iterator.
+ */
+SPHINXBASE_EXPORT
+void ngram_iter_free(ngram_iter_t *itor);
 
 /**
  * Add a word (unigram) to the language model.
@@ -482,6 +583,7 @@ ngram_model_set_iter_t *ngram_model_set_iter_next(ngram_model_set_iter_t *itor);
 /**
  * Finish iteration over a langauge model set.
  */
+SPHINXBASE_EXPORT
 void ngram_model_set_iter_free(ngram_model_set_iter_t *itor);
 
 /**
